find_routes library

Functions

findRoutes(BuildStep buildStep) Future<List<RouteDetail>>
Scans the source code for functions annotated with @Route and extracts route details.

Typedefs

RouteDetail = ({List<FormalParameterElement> bodyParams, String functionName, bool ignoreForClient, String import, HttpMethod method, String path, Set<String> pathParams, bool requiresAuth, bool requiresSuperUserAuth, DartType returnType})
Represents the details of a server route extracted from annotated functions.