RouteBuilder class

Builder that generates route handlers based on functions annotated with @Route. Generates two files: routes.dart with the actual route handlers and routes_info.dart with metadata about the routes for client generation.

Constructors

RouteBuilder()

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseParam(FormalParameterElement param) → Expression
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited