route_builder library
Classes
- RouteBuilder
- Builder that generates route handlers based on functions annotated with @Route. Generates two files: routes.dart with the actual route handlers and routes_info.dart with metadata about the routes for client generation.
Functions
-
routeBuilder(
BuilderOptions options) → Builder - Exposes the routeBuilder function to be used as a builder in build.yaml.